import * as React from 'react';
import { hot } from 'react-hot-loader'
import { Route, Router } from 'react-router';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import { ThemeProvider } from '@romanjaros/treejs-components/styled';
import PageLayout from '@romanjaros/treejs-components/Layout/containers';
import { IMenuItem } from '@romanjaros/treejs-components/Layout/types';

import ButtonPage from 'documentation/ButtonPage/components';
import CheckboxPage from 'documentation/CheckboxPage/components';
import GridPage from 'documentation/GridPage/components';
import ModalPage from 'documentation/ModalPage/components';
import RadioButtonPage from 'documentation/RadioButtonPage/components';
import SelectBoxPage from 'documentation/SelectBoxPage/components';
import DatePickerPage from 'documentation/DatePickerPage/components';
import TextFieldPage from 'documentation/TextFieldPage/components';
import FormsPage from 'documentation/FormsPage/components';
import WelcomePage from 'documentation/WelcomePage/components';
import FetchPage from 'documentation/FetchPage/components';
import SignInPage from 'documentation/ProfilePage/components/signin';
import SignOutPage from 'documentation/ProfilePage/components/signout';
import { THEME } from 'documentation/WelcomePage/constants';

import { MainStyle } from '../styles/App';
import history from '../utils/history';


const App = (): React.ReactElement => {
	const leftMenuItems: IMenuItem[] = [
		{ label: 'Button', href: '/button' },
		{ label: 'Checkbox', href: '/checkbox' },
		{ label: 'Grid', href: '/grid' },
		{ label: 'Modal', href: '/modal' },
		{ label: 'Radio', href: '/radioButton' },
		{ label: 'SelectBox', href: '/selectBox' },
		{ label: 'DatePicker', href: '/datePicker' },
		{ label: 'TextField', href: '/textField' },
		{ label: 'Forms', href: '/forms' },
	];

	const topMenuItems: IMenuItem[] = [
		{ label: 'Home', href: '/' },
		{ label: 'Fetch', href: '/fetch' },
		{ label: 'Sign in', href: '/signin', isMain: false },
	];

	const themeName = window.localStorage.getItem(THEME) || 'main';
	const theme = require(`@romanjaros/treejs-components/themes/${themeName}`).default;

	return (
		<ThemeProvider theme={theme}>
			<MainStyle>
				<PageLayout
					leftMenuItems={leftMenuItems}
					topMenuItems={topMenuItems}
					history={history}
					enableLeftMenu
					logo={<div><FontAwesomeIcon icon="tree" /> js</div>}
				>
					<Router history={history}>
						<Route path="/" exact component={WelcomePage} />
						<Route path="/button" component={ButtonPage} />
						<Route path="/checkbox" component={CheckboxPage} />
						<Route path="/grid" component={GridPage} />
						<Route path="/modal" component={ModalPage} />
						<Route path="/radioButton" component={RadioButtonPage} />
						<Route path="/selectBox" component={SelectBoxPage} />
						<Route path="/datePicker" component={DatePickerPage} />
						<Route path="/textField" component={TextFieldPage} />
						<Route path="/forms" component={FormsPage} />
						<Route path="/fetch" component={FetchPage} />
						<Route path="/signin" component={SignInPage} />
						<Route path="/signout" component={SignOutPage} />
					</Router>
				</PageLayout>
			</MainStyle>
		</ThemeProvider>
	);
};

export default hot(module)(App);
