import * as React from 'react';
import { connect } from 'react-redux';

import Button, { ButtonTypes } from '@romanjaros/treejs-components/Button';
import { Grid, GridCol } from '@romanjaros/treejs-components/Grid';
import ContentLoader from '@romanjaros/treejs-components/Loader/components/ContentLoader';
import { FetchMethod } from '@romanjaros/treejs-api/types';
import { getIsFetching } from '@romanjaros/treejs-api/selectors';

import { fetch } from '../actions';
import { getUrlKey } from '../utils';
import { getResponse } from 'documentation/FetchPage/selectors';


interface IProps {
	fetch: () => void;
	isFetching: boolean;
	response: any;
}

const FetchPage = (props: IProps): React.ReactElement => {
	return (
		<React.Fragment>
			<h2>Fetch endpoint</h2>

			<h3>Uživatel</h3>
			<Grid>
				<GridCol size={2}>
					<ContentLoader isLoading={props.isFetching}>
						<Button status={ButtonTypes.warning} title="Odeslat" onClick={props.fetch} />
					</ContentLoader>
				</GridCol>
			</Grid>

			<ContentLoader isLoading={props.isFetching}>
				<pre>
					{JSON.stringify(props.response, undefined, 2)}
				</pre>
			</ContentLoader>
		</React.Fragment>
	);
};

export default connect(
	(state) => ({
		response: getResponse(state),
		isFetching: getIsFetching(state, getUrlKey(FetchMethod.get)),
	}),
	{
		fetch,
	}
)(FetchPage);
