import * as React from 'react';
import * as Yup from 'yup';

import { Grid, GridCol, HORIZONTAL_ALIGN } from '@romanjaros/treejs-components/Grid';
import Field from '@romanjaros/treejs-forms/components/Field';
import Button from '@romanjaros/treejs-components/Button';
import { FIELD_TYPE } from '@romanjaros/treejs-forms/constants';
import { Form } from '@romanjaros/treejs-forms/components/Form';
import { IForm } from '@romanjaros/treejs-types/form';

import { customRender } from '../../RadioButtonPage/components/customRender';


interface FormValues {
	radiobutton: string;
}

export class CustomComponentForm extends React.PureComponent implements IForm<FormValues> {
	public initialValues: FormValues = {
		radiobutton: '',
	};

	public validationSchema = Yup.object().shape({
		text: Yup.string()
			.required('Field is required!'),
		radiobutton: Yup.string()
			.required('Field is required!'),
		selectbox: Yup.string()
			.required('Field is required!'),
		datePicker: Yup.string()
			.required('Field is required!')
	});

	public handleSubmit = (values: FormValues): void => {
		console.info(values);
	};

	public render(): React.ReactElement {

		const radioOptions = [
			{ name: 'Právnická osoba', code: 'legal' },
			{ name: 'Fyzická osoba', code: 'natural' },
		];

		return (
			<Form<FormValues>
				initialValues={this.initialValues}
				onSubmit={this.handleSubmit}
				validationSchema={this.validationSchema}
			>
				{({ errors }): React.ReactElement => (
					<React.Fragment>
						<Grid>
							<GridCol size={3}>
								<Field
									name="radiobutton"
									title="Radio Button"
									error={errors.radiobutton}
									options={radioOptions}
									horizontal
									customRender={customRender}
									component={FIELD_TYPE.RADIO_BUTTON}
								/>
							</GridCol>
						</Grid>
						<Grid horizontalAlign={HORIZONTAL_ALIGN.CENTER}>
							<GridCol size={3}>
								<Button
									type="submit"
									title="Send" />
							</GridCol>
						</Grid>
					</React.Fragment>
				)}
			</Form>
		);
	}
}

export default CustomComponentForm;
