import * as React from 'react';
import * as Yup from 'yup';

import { Grid, GridCol, HORIZONTAL_ALIGN } from '@romanjaros/treejs-components/Grid';
import Field from '@romanjaros/treejs-forms/components/Field';
import Button from '@romanjaros/treejs-components/Button';

import { FIELD_TYPE } from '@romanjaros/treejs-forms/constants';
import { Form } from '@romanjaros/treejs-forms/components/Form';
import { IForm } from '@romanjaros/treejs-types/form';


interface FormValues {
	checkbox: boolean;
	datePicker: string;
	radiobutton: string;
	selectbox: string;
	text: string;
}

export class ExampleForm extends React.PureComponent implements IForm<FormValues> {
	public initialValues: FormValues = {
		text: '',
		checkbox: null,
		radiobutton: '',
		selectbox: '',
		datePicker: '',
	};

	public validationSchema = Yup.object().shape({
		text: Yup.string()
			.required('Field is required!'),
		radiobutton: Yup.string()
			.required('Field is required!'),
		selectbox: Yup.string()
			.required('Field is required!'),
		datePicker: Yup.string()
			.required('Field is required!')
	});

	public handleSubmit = (values: FormValues): void => {
		console.info(values);
	};

	public render(): React.ReactElement {

		const radioOptions = [
			{ name: 'Field 1', code: 'field1' },
			{ name: 'Field 2', code: 'field2' }
		];

		const selectBoxOptions = [
			{ name: 'Option 1', code: 'option1' },
			{ name: 'Option 2', code: 'option2' }
		];

		return (
			<Form<FormValues>
				initialValues={this.initialValues}
				onSubmit={this.handleSubmit}
				validationSchema={this.validationSchema}
			>
				{({ errors }): React.ReactElement => (
					<React.Fragment>
						<Grid>
							<GridCol size={3}>
								<Field
									name="text"
									title="Input"
									error={errors.text}
									component={FIELD_TYPE.TEXT_FIELD}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="checkbox"
									title="Checkbox"
									error={errors.checkbox}
									component={FIELD_TYPE.CHECKBOX}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="radiobutton"
									title="Radio Button"
									error={errors.radiobutton}
									options={radioOptions}
									component={FIELD_TYPE.RADIO_BUTTON}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="selectbox"
									title="Selectbox"
									error={errors.selectbox}
									options={selectBoxOptions}
									component={FIELD_TYPE.SELECT_BOX}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="datePicker"
									title="DatePicker"
									error={errors.datePicker}
									component={FIELD_TYPE.DATE_PICKER}
								/>
							</GridCol>
						</Grid>
						<Grid horizontalAlign={HORIZONTAL_ALIGN.CENTER}>
							<GridCol size={3} >
								<Button
									type="submit"
									title="Send" />
							</GridCol>
						</Grid>
					</React.Fragment>
				)}
			</Form>
		);
	}
}

export default ExampleForm;
