require('ts-node/register');

const webpack = require('webpack');
const HtmlWebPackPlugin = require('html-webpack-plugin');

const { PORT } = require('./src/config');


module.exports = (env, args) => {
	return {
		entry: __dirname + `/src/index.tsx`,
		output: {
			filename: 'index.js',
			path: __dirname + (args.mode === 'development' ? '/dist' : `/../../dist/client`)
		},
		mode: args.mode === 'development' ? 'development' : 'production',
		devtool: 'source-map',
		resolve: {
			alias: {
				documentation: __dirname + '/src/modules',
				'@romanjaros/treejs-components': '@romanjaros/treejs-components/src',
				'@romanjaros/treejs-api': '@romanjaros/treejs-api/src',
				'@romanjaros/treejs-auth': '@romanjaros/treejs-auth/src',
				'@romanjaros/treejs-constants': '@romanjaros/treejs-constants/src',
				'@romanjaros/treejs-redux': '@romanjaros/treejs-redux/src',
				'@romanjaros/treejs-forms': '@romanjaros/treejs-forms/src',
				'@romanjaros/treejs-types': '@romanjaros/treejs-types/src',
				'@romanjaros/treejs-utils': '@romanjaros/treejs-utils/src',
			},
			extensions: ['.ts', '.tsx', '.js', '.json'],
		},
		module: {
			rules: [
				{
					test: /\.tsx?$/,
					loader: 'awesome-typescript-loader',
					options: {
						configFileName: __dirname + `/../../tsconfig.json`
					},
				},
				{
					enforce: 'pre',
					test: /\.js$/,
					loader: 'source-map-loader'
				}
			]
		},
		plugins: [
			new HtmlWebPackPlugin({
				hash: true,
				filename: 'index.html',  //target html
				template: __dirname + '/src/assets/html/index.html' //source html
			}),
			new webpack.HotModuleReplacementPlugin(),
		],
		devServer: {
			port: PORT,
			hot: true,
			host: '0.0.0.0',
			historyApiFallback: true,
		}
	}
};
