import { Middleware } from 'redux';
import { is } from 'ramda';

import { IAction } from '@romanjaros/treejs-types/redux/actions';

import { IFetchConfig } from './types';
import { fetchStatusActions } from './actions';
import { FetchActions } from './constants';


interface ISettings {
	BASE_ENDPOINT_URL: string;
}

export const FetchEndpoint = (setting: ISettings): Middleware => (store) => (next) => (action: IAction<IFetchConfig>) => {
	if (action.type === FetchActions.FETCH) {
		store.dispatch(fetchStatusActions.beforeRequest(action.payload));
		fetch(`${setting.BASE_ENDPOINT_URL}${action.payload.url}`)
			.then((response) => {
				return response.json();
			})
			.then((asJson) => {
				store.dispatch(fetchStatusActions.onSuccess(action.payload));
				if (is(Function, action.payload.onSuccess)) {
					action.payload.onSuccess(asJson);
				}
			})
			.catch((error) => {
				store.dispatch(fetchStatusActions.onError(action.payload));
				if (is(Function, action.payload.onError)) {
					action.payload.onError(error);
				}
			})
	}

	return next(action);
};
