import * as React from 'react';
import { connect } from 'react-redux';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'

import { isNilOrEmpty, noop } from '@romanjaros/treejs-utils';
import { STATUS } from '@romanjaros/treejs-types/common';
import { IHTMLElement } from '@romanjaros/treejs-types/form';

import { addModal, closeModal } from '../../Modal/actions';
import { IModalId, IModalState } from '../../Modal/types';
import { addModalComponent } from '../../Modal/utils/registerModal';
import TextField from '../../TextField';

import { StyledSelectBox } from '../style';
import Modal from '../components/Modal';


export interface IProps<V = string> extends IHTMLElement<V> {
	closeModal: (name: IModalId) => void;
	format?: string;
	openModal: (options: IModalState) => void;
	status?: STATUS;
	value?: string;
}

interface IState {
	value: string;
}

class DatePicker extends React.PureComponent<IProps, IState> {
	public static defaultProps = {
		onChange: noop,
	};

	public readonly state = {
		value: null as string,
	};

	public componentDidMount(): void {
		if (!isNilOrEmpty(this.props.value)) {
			this.setState({
				value: this.props.value,
			});
		}
	}

	private handleBlur = (value: string, e: React.FocusEvent<HTMLInputElement>): void => {
		if (this.props.onBlur) {
			this.props.onBlur(value, e);
		}
	};

	private handleDateClick = (value: string): void => {
		this.setState({ value });
		this.props.onChange(value, null);
	};

	private handleDateRemove = (): void => {
		this.setState({
			value: null,
		});
		this.props.onChange(null, null);
	};

	private openModal = (): void => {
		const {
			name,
			title,
			closeModal,
		} = this.props;

		const {
			value,
		} = this.state;

		addModalComponent(
			name,
			<Modal
				name={name}
				value={value}
				closeModal={closeModal}
				onChange={this.handleDateClick}
				onRemove={this.handleDateRemove}
			/>
		);
		this.props.openModal({ name, title, width: 400 });
	};

	public render(): React.ReactElement {
		const {
			name,
			title,
			status,
		} = this.props;

		const {
			value,
		} = this.state;

		return (
			<StyledSelectBox id={name}>
				<TextField
					name={name}
					title={title}
					rightIcon={<FontAwesomeIcon icon="calendar-alt" />}
					onClick={this.openModal}
					onFocus={this.openModal}
					onBlur={this.handleBlur}
					value={value}
					status={status}
					readonly
				/>
			</StyledSelectBox>
		);
	}
}

export default connect(
	null,
	{
		openModal: addModal,
		closeModal,
	},
)(DatePicker);
