import * as React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { History } from 'history';

import Modals from '../../Modal/containers/Modals';

import { IMenuItem } from '../types';
import {
	StyledLeftMenuLabel,
	StyledLeftMenu,
	StyledLeftMenuItem,
	StyledRightSide,
	StyledTopMenu,
	StyledPageContent,
	StyledLeftMenuLogo,
	StyledTopMenuItem,
	StyledTopLeftMenuItem,
	StyledTopMenuItemHamburger,
	StyledTopMenuItemLogo,
} from '../style';


interface IProps {
	enableLeftMenu: boolean;
	history: History;
	leftMenuItems?: IMenuItem[];
	logo: React.ReactElement;
	topMenuItems?: IMenuItem[];
}

interface IState {
	open: boolean;
}

class PageLayout extends React.PureComponent<IProps, IState> {
	public static defaultProps = {
		enableLeftMenu: true,
	};

	public readonly state = {
		open: false,
	};

	private toggleOpenLeftMenu = () => {
		this.setState({
			open: !this.state.open,
		});
	};

	private closeLeftMenu = () => {
		if (this.state.open) {
			this.setState({
				open: false,
			});
		}
	};

	private openPage = (href: string) => () => {
		this.props.history.push(href);
		this.setState({
			open: false,
		});
	};

	public render(): React.ReactElement {
		const {
			leftMenuItems,
			topMenuItems,
			children,
			logo,
			enableLeftMenu,
		} = this.props;
		const {
			open,
		} = this.state;

		return (
			<React.Fragment>
				<StyledLeftMenu open={open} enableLeftMenu={enableLeftMenu}>
					{
						enableLeftMenu && (
							<StyledLeftMenuLogo>
								{logo}
							</StyledLeftMenuLogo>
						)
					}
					{
						leftMenuItems && leftMenuItems.map(
							({ label, href }, i) => (
								<StyledLeftMenuItem key={i} onClick={this.openPage(href)}>
									<StyledLeftMenuLabel open={open}>
										{label}
									</StyledLeftMenuLabel>
								</StyledLeftMenuItem>
							)
						)
					}
				</StyledLeftMenu>
				<StyledRightSide open={open} enableLeftMenu={enableLeftMenu}>
					<StyledTopMenu>
						{
							!enableLeftMenu && (
								<StyledTopMenuItemLogo>
									{logo}
								</StyledTopMenuItemLogo>
							)
						}
						{
							enableLeftMenu && (
								<StyledTopMenuItemHamburger onClick={this.toggleOpenLeftMenu}>
									<FontAwesomeIcon icon="bars" />
								</StyledTopMenuItemHamburger>
							)
						}
						{
							topMenuItems && topMenuItems.map(
								({ label, href, isMain = true }, i) =>
									isMain
										? (
											<StyledTopMenuItem key={i} onClick={this.openPage(href)}>
												{label}
											</StyledTopMenuItem>
										)
										: (
											<StyledTopLeftMenuItem key={i} onClick={this.openPage(href)}>
												{label}
											</StyledTopLeftMenuItem>
										)
							)
						}
					</StyledTopMenu>
					<StyledPageContent open={open} enableLeftMenu={enableLeftMenu} onClick={this.closeLeftMenu}>
						{children}
					</StyledPageContent>
				</StyledRightSide>

				<Modals />
			</React.Fragment>
		);
	}
}

export default PageLayout;
