import * as React from 'react';
import { connect } from 'react-redux';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { closeModal } from '../actions';
import { modals } from '../selectors';
import { IModalReducer } from '../types';
import {
	StyledModalContainer,
	StyledModal,
	StyledCloseButton,
	StyledModalHeader,
	StyledModalBody
} from '../styles/modal';
import { getModalComponent } from '../utils/registerModal';



interface IProps {
	closeModal: (name: string) => void;
	modals: IModalReducer;
}

class Modals extends React.PureComponent<IProps> {
	private closeModal = (name: string) => (): void => {
		this.props.closeModal(name);
	};

	private unhandledClick = (e: React.FormEvent<HTMLDivElement>) => {
		e.stopPropagation();
	};

	public render(): React.ReactElement {
		const {
			modals,
		} = this.props;

		if (isNilOrEmpty(modals)) {
			return null;
		}

		return (
			<React.Fragment>
				{
					Object.keys(modals).map(
						(key) => {
							const modal = modals[key];
							return (
								<StyledModalContainer
									key={key}
									onClick={this.closeModal(key)}
								>
									<StyledModal
										width={modal.width}
										onClick={this.unhandledClick}
									>
										<StyledCloseButton
											onClick={this.closeModal(key)}
										>
											<FontAwesomeIcon icon="times" />
										</StyledCloseButton>
										<StyledModalHeader>
											{modal.title}
										</StyledModalHeader>
										<StyledModalBody>
											{getModalComponent(key)}
										</StyledModalBody>
									</StyledModal>
								</StyledModalContainer>
							)
						}
					)
				}
			</React.Fragment>
		);
	}
}

export default connect(
	(state) => ({
		modals: modals(state),
	}),
	{
		closeModal,
	}
)(Modals);
