import * as React from 'react';
import { Formik, FormikProps, FormikActions } from 'formik';

import { FormErrors } from '@romanjaros/treejs-types/form';


interface IProps<FormValues> {
	children: (props: FormikProps<FormValues>) => React.ReactElement;
	initialValues: FormValues;
	onSubmit: (values: FormValues, actions: FormikActions<FormValues>) => void;
	validate?: (values: FormValues) => FormErrors<FormValues>;
	validationSchema: any;
}

export class Form<FormValues> extends React.PureComponent<IProps<FormValues>> {
	public render(): React.ReactElement {
		const {
			children,
			onSubmit,
			validate,
			initialValues,
			validationSchema,
		} = this.props;

		return (
			<Formik
				onSubmit={onSubmit}
				validate={validate}
				initialValues={initialValues}
				validationSchema={validationSchema}
				validateOnChange={false}
				validateOnBlur={false}
				render={(props: FormikProps<FormValues>): React.ReactElement => (
					<form onSubmit={props.handleSubmit}>
						{children(props)}
					</form>
				)}
			/>
		);
	}
}
