import * as React from 'react';
import { FieldProps } from 'formik';

import CheckBoxComponent, { IProps as ICheckboxFieldProps } from '@romanjaros/treejs-components/Checkbox';

import { StyledCheckboxErrorMessageContainer } from '../../style';


export interface IProps<V = string> extends ICheckboxFieldProps<V> {
	error?: string;
}

interface IAllProps extends IProps, FieldProps {}

const CheckboxField = (props: IAllProps): React.ReactElement => {
	const {
		field,
		title,
		error,
	} = props;

	const handleClick = (_: boolean, e: React.MouseEvent): void => {
		field.onChange(e);
	};
	const handleBlur = (_: boolean, e: React.FocusEvent): void => {
		field.onBlur(e);
	};

	return (
		<div>
			<CheckBoxComponent
				name={field.name}
				title={title}
				checked={field.value}
				onChange={handleClick}
				onBlur={handleBlur}
			/>
			<StyledCheckboxErrorMessageContainer>{error}</StyledCheckboxErrorMessageContainer>
		</div>
	);
};

export default CheckboxField;
