import * as React from 'react';
import { FieldProps } from 'formik';

import { STATUS } from '@romanjaros/treejs-types/common';

import DatePickerComponent, { IProps as IRadioButtonProps } from '@romanjaros/treejs-components/DatePicker/containers';
import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { StyledTextFieldErrorMessageContainer } from '../../style';


export interface IProps<V = string> extends IRadioButtonProps<V> {
	error?: string;
}

interface IAllProps extends IProps, FieldProps {}

const DatePicker = (props: IAllProps): React.ReactElement => {
	const {
		field,
		form: {
			setFieldValue,
		},
		title,
		error,
	} = props;

	const handleChange = (value: string): void => {
		setFieldValue(field.name, value);
	};

	const handleBlur = (_: string ,e: React.FocusEvent<HTMLInputElement>): void => {
		field.onBlur(e);
	};

	const status = !isNilOrEmpty(error) && STATUS.error;

	return (
		<div>
			<DatePickerComponent
				name={field.name}
				title={title}
				value={field.value}
				onChange={handleChange}
				onBlur={handleBlur}
				status={status}
			/>
			<StyledTextFieldErrorMessageContainer>{error}</StyledTextFieldErrorMessageContainer>
		</div>
	);
};

export default DatePicker;
