import * as React from 'react';
import { FieldProps } from 'formik';

import { STATUS } from '@romanjaros/treejs-types/common';

import SelectBoxComponent, { IProps as ISelectBoxFieldProps } from '@romanjaros/treejs-components/SelectBox/containers';
import { IOption } from '@romanjaros/treejs-components/SelectBox/types';
import { isNilOrEmpty } from '@romanjaros/treejs-utils';

import { StyledTextFieldErrorMessageContainer } from '../../style';


export interface IProps<V = IOption> extends ISelectBoxFieldProps<V> {
	error?: string;
	options: IOption[];
}

interface IAllProps extends IProps, FieldProps {}

const SelectBox = (props: IAllProps): React.ReactElement => {
	const {
		field,
		form: {
			setFieldValue,
		},
		title,
		error,
		options,
	} = props;

	const handleChange = (option: IOption): void => {
		if (isNilOrEmpty(option)) {
			setFieldValue(field.name, undefined);
		} else {
			setFieldValue(field.name, option.code);
		}
	};

	const handleBlur = (_: IOption, e: React.FocusEvent<HTMLInputElement>): void => {
		field.onBlur(e);
	};

	const status = !isNilOrEmpty(error) && STATUS.error;

	return (
		<div>
			<SelectBoxComponent
				name={field.name}
				title={title}
				value={field.value}
				options={options}
				onChange={handleChange}
				onBlur={handleBlur}
				status={status}
			/>
			<StyledTextFieldErrorMessageContainer>{error}</StyledTextFieldErrorMessageContainer>
		</div>
	);
};

export default SelectBox;
